user/dev discussion of public-inbox itself
 help / color / mirror / code / Atom feed
Search results ordered by [date|relevance]  view[summary|nested|Atom feed]
thread overview below | download mbox.gz: |
* [PATCH 4/6] qspawn: improve variable naming and commenting
  2019-09-17  8:31  7% [PATCH 0/6] qspawn-related cleanups, comments, and minor fix Eric Wong
@ 2019-09-17  8:31  6% ` Eric Wong
  0 siblings, 0 replies; 2+ results
From: Eric Wong @ 2019-09-17  8:31 UTC (permalink / raw)
  To: meta

Naming $start_cb consistently helps avoid confusing new readers,
and some comments will help with understanding flow
---
 lib/PublicInbox/GitHTTPBackend.pm |  2 +-
 lib/PublicInbox/Qspawn.pm         | 16 +++++++++-------
 2 files changed, 10 insertions(+), 8 deletions(-)

diff --git a/lib/PublicInbox/GitHTTPBackend.pm b/lib/PublicInbox/GitHTTPBackend.pm
index c9a7cff..ec8e651 100644
--- a/lib/PublicInbox/GitHTTPBackend.pm
+++ b/lib/PublicInbox/GitHTTPBackend.pm
@@ -204,7 +204,7 @@ sub serve_smart {
 	$env{PATH_TRANSLATED} = "$git->{git_dir}/$path";
 	my $rdr = input_prepare($env) or return r(500);
 	my $qsp = PublicInbox::Qspawn->new([qw(git http-backend)], \%env, $rdr);
-	$qsp->psgi_return($env, $limiter, sub {
+	$qsp->psgi_return($env, $limiter, sub { # parse_hdr
 		my ($r, $bref) = @_;
 		my $res = parse_cgi_headers($r, $bref) or return; # incomplete
 		$res->[0] == 403 ? serve_dumb($env, $git, $path) : $res;
diff --git a/lib/PublicInbox/Qspawn.pm b/lib/PublicInbox/Qspawn.pm
index 10fe534..5a30064 100644
--- a/lib/PublicInbox/Qspawn.pm
+++ b/lib/PublicInbox/Qspawn.pm
@@ -44,7 +44,7 @@ sub new ($$$;) {
 }
 
 sub _do_spawn {
-	my ($self, $cb, $limiter) = @_;
+	my ($self, $start_cb, $limiter) = @_;
 	my $err;
 	my ($cmd, $env, $opts) = @{$self->{args}};
 	my %opts = %{$opts || {}};
@@ -66,7 +66,7 @@ sub _do_spawn {
 	} else {
 		$self->{err} = $!;
 	}
-	$cb->($self->{rpipe});
+	$start_cb->($self->{rpipe});
 }
 
 sub child_err ($) {
@@ -135,11 +135,11 @@ sub finish ($;$) {
 }
 
 sub start {
-	my ($self, $limiter, $cb) = @_;
+	my ($self, $limiter, $start_cb) = @_;
 	if ($limiter->{running} < $limiter->{max}) {
-		_do_spawn($self, $cb, $limiter);
+		_do_spawn($self, $start_cb, $limiter);
 	} else {
-		push @{$limiter->{run_queue}}, [ $self, $cb ];
+		push @{$limiter->{run_queue}}, [ $self, $start_cb ];
 	}
 }
 
@@ -175,11 +175,12 @@ reread:
 		}
 	};
 	$limiter ||= $def_limiter ||= PublicInbox::Qspawn::Limiter->new(32);
-	$self->start($limiter, sub { # may run later, much later...
+	$self->start($limiter, sub { # start_cb, may run later, much later...
 		($rpipe) = @_; # popen_rd result
 		if ($async) {
 		# PublicInbox::HTTPD::Async->new($rpipe, $cb, $end)
 			$async = $async->($rpipe, $cb, $end);
+			# $cb will call ->async_pass or ->close
 		} else { # generic PSGI
 			$cb->() while $qx;
 		}
@@ -254,7 +255,7 @@ sub psgi_return {
 		$ret;
 	};
 
-	my $wcb = delete $env->{'qspawn.wcb'};
+	my $wcb = delete $env->{'qspawn.wcb'}; # or PSGI server supplies it
 	my $async = $env->{'pi-httpd.async'};
 
 	my $cb = sub {
@@ -287,6 +288,7 @@ sub psgi_return {
 		if ($async) {
 			# PublicInbox::HTTPD::Async->new($rpipe, $cb, $end)
 			$async = $async->($rpipe, $cb, $end);
+			# $cb will call ->async_pass or ->close
 		} else { # generic PSGI
 			$cb->() while $rd_hdr;
 		}
-- 
EW


^ permalink raw reply related	[relevance 6%]

* [PATCH 0/6] qspawn-related cleanups, comments, and minor fix
@ 2019-09-17  8:31  7% Eric Wong
  2019-09-17  8:31  6% ` [PATCH 4/6] qspawn: improve variable naming and commenting Eric Wong
  0 siblings, 1 reply; 2+ results
From: Eric Wong @ 2019-09-17  8:31 UTC (permalink / raw)
  To: meta

Still haven't found anything which is causing problems on korg,
but found a bunch of worthwhile cleanups, clarifications
and perhaps minor efficiency improvements that I'm comfortable
putting on 'master'.

Eric Wong (6):
  qspawn: remove return value from ->finish
  qspawn: log errors for generic PSGI server users
  qspawn: shorten lifetime of circular references
  qspawn: improve variable naming and commenting
  http: drop unused `$env' variable after delete
  http: remove unnecessary delete

 lib/PublicInbox/GitHTTPBackend.pm |  2 +-
 lib/PublicInbox/HTTP.pm           |  6 ++--
 lib/PublicInbox/Qspawn.pm         | 48 ++++++++++++-------------------
 t/qspawn.t                        | 17 +++++++----
 4 files changed, 33 insertions(+), 40 deletions(-)

-- 
EW


^ permalink raw reply	[relevance 7%]

Results 1-2 of 2 | reverse | options above
-- pct% links below jump to the message on this page, permalinks otherwise --
2019-09-17  8:31  7% [PATCH 0/6] qspawn-related cleanups, comments, and minor fix Eric Wong
2019-09-17  8:31  6% ` [PATCH 4/6] qspawn: improve variable naming and commenting Eric Wong

Code repositories for project(s) associated with this public inbox

	https://80x24.org/public-inbox.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).